@@ -5,15 +5,15 @@ use warnings;
 
 use App::Environ;
 use App::Environ::Config;
-use AnyEvent;
 use Carp qw( croak );
 
 App::Environ::Config->register( qw( bar.yml ) );
 
 App::Environ->register( __PACKAGE__,
-  initialize   => sub { __PACKAGE__->_initialize(@_) },
-  reload       => sub { __PACKAGE__->_reload(@_) },
-  'finalize:r' => sub { __PACKAGE__->_finalize(@_) },
+  initialize       => sub { __PACKAGE__->_initialize(@_) },
+  reload           => sub { __PACKAGE__->_reload(@_) },
+  'pre_finalize:r' => sub { __PACKAGE__->_pre_finalize(@_) },
+  'finalize:r'     => sub { __PACKAGE__->_finalize(@_) },
 );
 
 my $INSTANCE;
@@ -29,45 +29,38 @@ sub instance {
 
 sub _initialize {
   my $class = shift;
-  my $cb    = pop if ref( $_[-1] ) eq 'CODE';
+  my @args  = @_;
 
   my $bar_config = App::Environ::Config->instance->{'bar'};
 
   $INSTANCE = {
-    config     => $bar_config,
-    init_args  => [@_],
-    reload_cnt => 0,
+    config    => $bar_config,
+    init_args => \@args,
+    reloads   => 0,
   };
 
-  if ( defined $cb ) {
-    AE::postpone { $cb->() };
-  }
-
   return;
 }
 
 sub _reload {
-  my $cb = pop if ref( $_[-1] ) eq 'CODE';
-
   $INSTANCE->{config} = App::Environ::Config->instance->{'bar'};
-  $INSTANCE->{reload_cnt}++;
+  $INSTANCE->{reloads}++;
 
-  if ( defined $cb ) {
-    AE::postpone { $cb->() };
-  }
+  return;
+}
+
+sub _pre_finalize {
+  my $class    = shift;
+  my $need_err = shift;
+  my $cb       = shift;
+
+  $cb->();
 
   return;
 }
 
 sub _finalize {
-  my $cb = pop if ref( $_[-1] ) eq 'CODE';
-
   undef $INSTANCE;
-
-  if ( defined $cb ) {
-    AE::postpone { $cb->() };
-  }
-
   return;
 }
 
